<?php
namespace Teknisa\SUP\Modules\Cotacao\Modules\AnaliseCotacoes\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\Controller;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;

class ProdutoNaoCotado extends \Zeedhi\Framework\Controller\Report {

    protected $entityManager;
    protected $qr2Strategy;
    protected $newCode;
    protected $environment;
    protected $connection;
    protected $dataSourceManager;
    protected $birtStrategy;
    

    public function __construct($reportService, $entityManager, $qr2Strategy, $newCode, $environment, $connection, $dataSourceManager, $birtStrategy) {
        $this->entityManager     = $entityManager;
        $this->qr2Strategy       = $qr2Strategy;
        $this->reportService     = $reportService;
        $this->newCode           = $newCode;
        $this->environment       = $environment;
        $this->connection        = $connection;
        $this->dataSourceManager = $dataSourceManager;
        $this->birtStrategy = $birtStrategy;
    }
   
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        
        $row = $request->getRow();
        $row['P_NRORG'] = $this->environment->getNrorgTrab();
        $row['__report_name'] = $row['REPORT'];
        $row['CDFILIAL'] = $this->getCdFilial();
        $row['CDFILLANCA'] = $row['CDFILLANCA'];
        $row['NRSOLICMP'] = $row['NRSOLICMP'];
        $row['CDOPERADOR'] = $row['CDOPERADOR'];
        $row['CDREGIAO'] = $row['CDREGIAO'];
        $row['CDFILSOLI'] = $row['CDFILSOLI'];
        $row['CDFILDEST'] = $row['CDFILSOLI'];
        $row['DTINICIAL'] = $row['DT_ENTREGA']['start'];
        $row['DTFINAL'] = $row['DT_ENTREGA']['end'];
        $row['DTINICOT'] = $row['DT_VALIDADE']['start'];
        $row['DTFINCOT'] = $row['DT_VALIDADE']['end'];
        
        $nrlistaFilSoli = $this->criarListaValores($row['CDFILSOLI']);
        $row['CDFILSOLI'] = "_NRLISTA=".$nrlistaFilSoli;
        $row['CDFILDEST'] = "_NRLISTA=".$nrlistaFilSoli;

        $nrlistaFillanca = $this->criarListaValores($row['CDFILLANCA']);
        $row['CDFILLANCA'] = "_NRLISTA=".$nrlistaFillanca;
        
        if($row['CDREGIAO'] != 'T'){
            $nrlistaRegiao = $this->criarListaValores($row['CDREGIAO']);
            $row['CDREGIAO'] = "_NRLISTA=".$nrlistaRegiao;
        }
        
        if($row['CDOPERADOR'] != 'T'){
            $nrlistaOperador = $this->criarListaValores($row['CDOPERADOR']);
            $row['CDOPERADOR'] = "_NRLISTA=".$nrlistaRegiao;
        }
        
        if($row['NRSOLICMP'] != 'T'){
            $nrlistaSolic = $this->criarListaValores($row['NRSOLICMP']);
            $row['NRSOLICMP'] = "_NRLISTA=".$nrlistaSolic;
        }
        
        $this->initializeReportMapping();
        $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
    }
    
    public function initializeReportMapping() {
        $params = array (
            'strategy' => 'BIRT',
            'parameterMapping' =>
                array (
                        "CDFILIAL"    => "P_CDFILIAL",
                        "CDFILSOLI"   => "P_CDFILIALSOLI",
                        "CDFILLANCA"  => "P_CDFILIALLANC",
                        "CDREGIAO"    => "P_CDREGIAO",
                        "CDOPERADOR"  => "P_CDOPERADOR",
                        "NRSOLICMP"   => "P_NRSOLICMP",
                        "DTINICIAL"   => "P_DTINICIAL",
                        "DTFINAL"     => "P_DTFINAL",
                        "P_NRORG"     => "P_NRORG"
                ),
        );

        $this->reportMapping = array (
            'SUP04000' => $params,
            'SUP04001' => $params
        );
    }
     public function verificaIdsisdos(DTO\Request $request, DTO\Response $response) {
        
         $params = array(
    		"NRORG" => $this->environment->getNrorg()
    	);
    	
    	$sql = "SELECT IDSISDOS FROM PARAMGERAL WHERE NRORG = :NRORG";
    	$query = $this->connection->prepare($sql);
    	$query->execute($params);
    	$resp = $query->fetchAll();

    $response->addDataSet(new DataSet("resp", $resp));
      
    }
    public function getCdFilial() {
        $query = "SELECT DISTINCT
                    NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL)  AS CDFILIAL
                  FROM
                    FILIAL FIL,
                    FILIAL
                  WHERE
                    (FILIAL.CDFILIAL = :P_CDFILIAL) AND
                    NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) = FIL.CDFILIAL";
        $stmt = $this->connection->prepare($query);
        $stmt->execute(array(
            "P_CDFILIAL" => $this->environment->getCdFilial()
		));
        $cdfilial = $stmt->fetchAll()[0]["CDFILIAL"];
        return $cdfilial;
    }
    
    public function criarListaValores($valores){
       
            $this->entityManager->beginTransaction();
            $lista = explode('_',$valores);
            $nrlista = $this->newCode->getCodeByTableName('LISTA', $this->environment->getNrorgTrab(), 1, 10, false);
            try{
                foreach($lista as $key){
                    $this->insertLista($nrlista, $key);
                }
                $this->entityManager->commit();
                return $nrlista;
            } catch(\Exception $e){
                $this->entityManager->rollback();
                throw $e;
            }
        
    }
    //insere lista no banco
    public function insertLista($nrlista, $cdlista) {
        $params = array(
            "NRLISTA" => $nrlista,
            "CDLISTA" => $cdlista
        );
        
        $sql = "INSERT INTO LISTA (NRLISTA, CDLISTA) VALUES (:NRLISTA, :CDLISTA)";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    

            
    //         'SUP04011' =>
    //         array (
    //             'strategy' => 'QR2',
    //             'parameterMapping' =>
    //                 array (
    //                     "CDFILIAL"    => "P_CDFILIAL",
    //                     "CDFILSOLI"   => "P_CDFILIALSOLI",
    //                     "CDREGIAO"    => "P_CDREGIAO",
    //                     "CDOPERADOR"  => "P_CDCOMPRADOR",
    //                     "CDPRODINI"   => "P_CDPRODINI",
    //                     "CDPRODFIN"   => "P_CDPRODFIN",
    //                     "DTINICIAL"   => "P_DTINICIAL",
    //                     "DTFINAL"     => "P_DTFINAL",
    //                     "DTINICOT"    => "P_DTINICOT",
    //                     "DTFINCOT"    => "P_DTFINCOT",
    //                     "CDFILLANCA"  => "L_CDFILIALLANC",
    //                     "CDFILLANCA1" => "L_CDFILIALLANC1",
    //                     "CDFILLANCA2" => "L_CDFILIALLANC2",
    //                     "CDFILLANCA3" => "L_CDFILIALLANC3",
    //                     "NRSOLICMP"   => "L_SOLICITA",
    //                     "NRSOLICMP1"  => "L_SOLICITA1"
                      
                        
    //                 ),
    //         ),
    // );
    
}