<?php
namespace Teknisa\SUP\Modules\Cotacao\Modules\Pedido\Controllers;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;

class Sup02300PedidoColetaGeralController extends \Zeedhi\Framework\Controller\Report
{
    protected $qr2Strategy;
    protected $stNomeRel;
    protected $stExtensao;
    protected $supUtilities;
    protected $connection;
    protected $birtStrategy;
    protected $environment;
    protected $newCode;
    
    public  function __construct($reportService, $qr2Strategy, $supUtilities, $connection, $birtStrategy, $environment, $newCode)
    {
        parent::__construct($reportService);
        $this->qr2Strategy   =   $qr2Strategy;
        $this->supUtilities  =   $supUtilities;
        $this->connection    =   $connection;
        $this->birtStrategy  =   $birtStrategy;
        $this->environment   =   $environment;
        $this->newCode       = $newCode;
    }
    
    protected $reportMapping = array(
        'SUP02300' => array(
            'strategy' => 'BIRT',
            'parameterMapping' => array (
                "P_CDFILIAL"   => "P_CDFILIAL",
                "L_CDFORNECED" => "L_CDFORNECED",
                "L_CDMENSAGEM" => "L_CDMENSAGEM",
                "NRORG"        => "P_NRORG",
                "P_CDINI"      => "P_CDINI",
                "P_CDFIN"      => "P_CDFIN"
            )
        ),
        
        'SUP02301' => array(
            'strategy' => 'BIRT',
            'parameterMapping' => array (
                "P_CDFILIAL"   => "P_CDFILIAL",
                "L_CDFORNECED" => "L_CDFORNECED",
                "L_CDMENSAGEM" => "L_CDMENSAGEM",
                "NRORG"        => "P_NRORG",
                "P_CDINI"      => "P_CDINI",
                "P_CDFIN"      => "P_CDFIN"
            )
        )
    );
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response)
    {   
        $row = $request->getRow();
        $row['NRORG'] = $this->environment->getNrOrg();
        $this->qr2Strategy->setQr2Type($row['QR2TYPE']);
        $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
        if($row['L_CDFORNECED'] != 'T'){
            $nrlistaForn = $this->criarListaValores($row['L_CDFORNECED']);
            $row['L_CDFORNECED'] = "_NRLISTA=".$nrlistaForn;
        } 
        if($row['L_CDMENSAGEM'] != 'T'){
            $nrlistaMsg = $this->criarListaValores($row['L_CDMENSAGEM']);
            $row['L_CDMENSAGEM'] = "_NRLISTA=".$nrlistaMsg;
        }
    }
    
    protected function criarListaValores($lista)
    {
        $nrlista = $this->newCode->getCodeByTableName('LISTA', $this->environment->getNrOrg());
        $valores = explode('_',$lista);
        try{
            foreach($valores as $key){
                $this->insertLista($nrlista, $key);
            }
            return $nrlista;
        } catch(\Exception $e){
            throw $e;
        }
     }

     public function insertLista($nrlista, $cdlista) 
     {
        $params = array(
            "NRLISTA" => $nrlista,
            "CDLISTA" => $cdlista
        );

        $sql = "INSERT INTO LISTA (NRLISTA, CDLISTA) VALUES (:NRLISTA, :CDLISTA)";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
}


